@@ -41,14 +41,16 @@ class ViewOne(SimplePanel):
                 # with respect to the other members of the container.
                 grd.add(
                     Entry(
-                        binding=self.bind("value_1"), validator=validators.int_validator
+                        binding=self.bind("value_1"),
+                        validator=validators.float_validator,
                     ),
                     weight=6,
                     margin=3,
                 )
                 grd.add(
                     Entry(
-                        binding=self.bind("value_1"), validator=validators.int_validator
+                        binding=self.bind("value_1"),
+                        validator=validators.float_validator,
                     ),
                     weight=4,
                     margin=3,
