@@ -1,16 +1,17 @@
 import logging
 import pytest
-from pydantic import ValidationError
+
 
 from aio_wx_widgets.widgets.validators.validators import (
     int_validator,
     all_digits_validator,
+    ValidationError,
 )
 
 _LOGGER = logging.getLogger(__name__)
 
 
-@pytest.mark.parametrize("incoming,expected", [("0", 0), ("01", 1), ("-1", -1)])
+@pytest.mark.parametrize("incoming,expected", [("0", 0), ("1", 1), ("-1", -1)])
 def test_int_validator(incoming, expected):
 
     result = int_validator(incoming)
@@ -19,7 +20,7 @@ def test_int_validator(incoming, expected):
     assert result == expected
 
 
-@pytest.mark.parametrize("incoming", [None, "a"])
+@pytest.mark.parametrize("incoming", ["a"])
 def test_int_validator_fail(incoming):
     with pytest.raises(ValidationError):
         int_validator(incoming)
